@@ -6,6 +6,6 @@ class ApiResponseError(Exception):
             name -- error name
             status_code -- http response error code
     """
-    def __init__(self, url, status_code):
+    def __init__(self, url, message='Error YOM API'):
         self.url = url
-        self.status_code = status_code
+        self.message = message
